
#   ___________    __    ____  __  .______   ____    ____
#  |   ____\   \  /  \  /   / |  | |   _  \  \   \  /   /
#  |  |__   \   \/    \/   /  |  | |  |_)  |  \   \/   /
#  |   __|   \            /   |  | |   ___/    \_    _/
#  |  |       \    /\    /    |  | |  |          |  |
#  |__|        \__/  \__/     |__| | _|          |__|


__title__ = 'fwipy'
__description__ = 'Fwipy - Python Wrapper for Content Player Socket Operations'
__url__ = 'https://github.com/FourWindsInteractive/fwipy'
__version__ = '0.0.1.dev0'
__author__ = "Erin O'Connell"
__author_email__ = 'erin.oconnell@fourwindsinteractive.com'
__license__ = 'Apache 2.0'
__copyright__ = "Copyright 2017 Erin O'Connell"
__download_url__ = 'https://github.com/fourwindsinteractive/fwipy/archive/{0}.tar.gz'.format(__version__)